@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2011-2018 Luis Falcon <falcon@gnu.org>
-#    Copyright (C) 2011-2018 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2011-2019 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2011 Cédric Krier
 
 #    This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@ info = dict(config.items('tryton'))
 for key in ('depends', 'extras_depend', 'xml'):
     if key in info:
         info[key] = info[key].strip().splitlines()
-major_version, minor_version = 4, 6
+major_version, minor_version = 5, 0
 
 requires = ['pytz','numpy']
 
@@ -55,11 +55,11 @@ requires.append('trytond >= %s.%s, < %s.%s' %
 
 setup(name='gnuhealth',
     version=info.get('version', '0.0.1'),
-    description=info.get('description', 'GNU Health - The Free/Libre Hospital and Health Information System core package for Tryton'),
+    description=info.get('description', 'GNU Health - The Free/Libre Hospital and Health Information System'),
     long_description=read('README'),
     author='GNU Solidario',
     author_email='health@gnusolidario.org',
-    url='http://health.gnu.org',
+    url='https://www.gnuhealth.org',
     download_url='http://ftp.gnu.org/gnu/health/',
     package_dir={'trytond.modules.health': '.'},
     packages=[
