@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2018 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2018 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2019 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2019 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,6 @@ from trytond.model import ModelView, ModelSQL, ModelSingleton, fields, Unique
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.pyson import Eval, Not, Bool, PYSONEncoder, Equal, And, Or, If
-from pymongo import MongoClient
-from pymongo.errors import ConnectionFailure
 import requests
 import json
 from uuid import uuid4
@@ -116,6 +114,9 @@ class FederationNodeConfig(ModelSingleton, ModelSQL, ModelView):
         else:
             protocol = 'http://'
 
+        if (not user or not password):
+            cls.raise_user_error("Please setup the login credentials")
+
         url = protocol + host + ':' + str(port) + '/people/' + user
 
         try:
@@ -194,9 +195,16 @@ class FederationQueue(ModelSQL, ModelView):
         # Get the Institution code as the originating node.
         HealthInst = Pool().get('gnuhealth.institution')
         institution = HealthInst.get_institution()
-        institution_code, = HealthInst.search_read([("name", "=", institution)],
-            limit=1, fields_names=['code'])
-        return institution_code['code']
+
+        if (institution):
+            #Get the institution code associated to the ID
+            institution_code = HealthInst(institution).code
+
+        else:
+            FederationQueue.raise_user_error(
+                "You need to create a health Institution first")
+
+        return institution_code
 
     @classmethod
     def send_record(cls,record):
