@@ -2,14 +2,11 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pool import PoolMeta
-from trytond.transaction import Transaction
 from trytond import backend
 
 __all__ = ['Invoice', 'InvoiceLine']
-__metaclass__ = PoolMeta
 
-
-class Invoice:
+class Invoice(metaclass=PoolMeta):
     __name__ = 'account.invoice'
 
     patient = fields.Function(
@@ -42,29 +39,7 @@ class Invoice:
                     'gnuhealth.health_service.line')]
 
 
-    @classmethod
-    def __setup__(cls):
-        super(Invoice, cls).__setup__()
-
-    @classmethod
-    def __register__(cls, module_name):
-        cursor = Transaction().cursor
-        TableHandler = backend.get('TableHandler')
-        table = TableHandler(cursor, cls, module_name)
-
-        # We retrieve the patient
-        # from the invoice line origin
-        if table.column_exist('patient'):
-            table.drop_column('patient')
-
-        # Similarly, we retrieve the health_service
-        # from the invoice line origin
-        if table.column_exist('health_service'):
-            table.drop_column('health_service')
-
-        super(Invoice, cls).__register__(module_name)
-
-class InvoiceLine:
+class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
     @classmethod
